@@ -20,7 +20,7 @@
 #include <QString>
 #include <QStringList>
 #include <QVariantList>
-#include <sys/stat.h>
+#include <qplatformdefs.h>
 
 namespace Kerfuffle
 {
@@ -84,7 +84,7 @@ public:
      * @note If returning false, make sure to emit the error() signal beforewards to notify
      * the user of the error condition.
      */
-    virtual bool extractFiles(const QVector<Archive::Entry *> &files, const QString &destinationDirectory, const ExtractionOptions &options) = 0;
+    virtual bool extractFiles(const QList<Archive::Entry *> &files, const QString &destinationDirectory, const ExtractionOptions &options) = 0;
 
     /**
      * @return Whether the plugins do NOT run the functions in their own thread.
@@ -105,14 +105,14 @@ public:
     /**
      * Returns the list of filenames retrieved from the list of entries.
      */
-    static QStringList entryFullPaths(const QVector<Archive::Entry *> &entries, PathFormat format = WithTrailingSlash);
+    static QStringList entryFullPaths(const QList<Archive::Entry *> &entries, PathFormat format = WithTrailingSlash);
 
     /**
      * Returns the list of the entries, excluding their children.
      *
      * This method relies on entries paths so doesn't require parents to be set.
      */
-    static QVector<Archive::Entry *> entriesWithoutChildren(const QVector<Archive::Entry *> &entries);
+    static QList<Archive::Entry *> entriesWithoutChildren(const QList<Archive::Entry *> &entries);
 
     /**
      * Returns the string list of entry paths, which will be a result of adding/moving/copying entries.
@@ -247,10 +247,10 @@ public:
      * the user of the error condition.
      */
     virtual bool
-    addFiles(const QVector<Archive::Entry *> &files, const Archive::Entry *destination, const CompressionOptions &options, uint numberOfEntriesToAdd = 0) = 0;
-    virtual bool moveFiles(const QVector<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options) = 0;
-    virtual bool copyFiles(const QVector<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options) = 0;
-    virtual bool deleteFiles(const QVector<Archive::Entry *> &files) = 0;
+    addFiles(const QList<Archive::Entry *> &files, const Archive::Entry *destination, const CompressionOptions &options, uint numberOfEntriesToAdd = 0) = 0;
+    virtual bool moveFiles(const QList<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options) = 0;
+    virtual bool copyFiles(const QList<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options) = 0;
+    virtual bool deleteFiles(const QList<Archive::Entry *> &files) = 0;
     virtual bool addComment(const QString &comment) = 0;
 
 Q_SIGNALS:
