@@ -10,8 +10,8 @@
 #include "plugin.h"
 
 #include <QHash>
+#include <QList>
 #include <QMimeType>
-#include <QVector>
 
 namespace Kerfuffle
 {
@@ -32,36 +32,36 @@ public:
      * An installed plugin is not necessarily available to the app.
      * The user could have disabled it from the settings, or the needed executables could not be found.
      */
-    QVector<Plugin *> installedPlugins() const;
+    QList<Plugin *> installedPlugins() const;
 
     /**
      * @return The list of plugins ready to be used. Includes read-only and read-write ones.
      */
-    QVector<Plugin *> availablePlugins() const;
+    QList<Plugin *> availablePlugins() const;
 
     /**
      * @return The list of read-write plugins ready to be used.
      */
-    QVector<Plugin *> availableWritePlugins() const;
+    QList<Plugin *> availableWritePlugins() const;
 
     /**
      * @return The list of plugins enabled by the user in the settings dialog.
      */
-    QVector<Plugin *> enabledPlugins() const;
+    QList<Plugin *> enabledPlugins() const;
 
     /**
      * @return The list of preferred plugins for the given @p mimeType, among all the available ones.
      * The list is sorted according to the plugins priority. The list is saved in a cache for efficiency.
      * If no plugin is available, returns an empty list.
      */
-    QVector<Plugin *> preferredPluginsFor(const QMimeType &mimeType);
+    QList<Plugin *> preferredPluginsFor(const QMimeType &mimeType);
 
     /**
      * @return The list of preferred read-write plugins for the given @p mimeType, among all the available ones.
      * The list is sorted according to the plugins priority.
      * If no read-write plugin is available, returns an empty list.
      */
-    QVector<Plugin *> preferredWritePluginsFor(const QMimeType &mimeType) const;
+    QList<Plugin *> preferredWritePluginsFor(const QMimeType &mimeType) const;
 
     /**
      * @return The preferred plugin for the given @p mimeType, among all the available ones.
@@ -88,7 +88,7 @@ public:
     /**
      * @return The subset of @p plugins that support either @p mimetype or a parent of @p mimetype.
      */
-    QVector<Plugin *> filterBy(const QVector<Plugin *> &plugins, const QMimeType &mimeType) const;
+    QList<Plugin *> filterBy(const QList<Plugin *> &plugins, const QMimeType &mimeType) const;
 
 private:
     void loadPlugins();
@@ -97,7 +97,7 @@ private:
      * @param readWrite whether to return only the read-write plugins.
      * @return The list of preferred plugins for @p mimeType among the available ones, sorted by priority.
      */
-    QVector<Plugin *> preferredPluginsFor(const QMimeType &mimeType, bool readWrite) const;
+    QList<Plugin *> preferredPluginsFor(const QMimeType &mimeType, bool readWrite) const;
 
     /**
      * @return A list with the given @p mimeTypes, alphabetically sorted according to their comment.
@@ -109,8 +109,8 @@ private:
      */
     static bool libarchiveHasLzo();
 
-    QVector<Plugin *> m_plugins;
-    QHash<QString, QVector<Plugin *>> m_preferredPluginsCache;
+    QList<Plugin *> m_plugins;
+    QHash<QString, QList<Plugin *>> m_preferredPluginsCache;
 };
 
 }
