@@ -12,7 +12,7 @@
 
 using namespace Kerfuffle;
 
-class KERFUFFLE_EXPORT CliPlugin : public Kerfuffle::CliInterface
+class CliPlugin : public Kerfuffle::CliInterface
 {
     Q_OBJECT
 
@@ -31,7 +31,7 @@ public:
     bool isFileExistsMsg(const QString &line) override;
     bool isFileExistsFileName(const QString &line) override;
 
-    bool moveFiles(const QVector<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options) override;
+    bool moveFiles(const QList<Archive::Entry *> &files, Archive::Entry *destination, const CompressionOptions &options) override;
     int moveRequiredSignals() const override;
 
 private Q_SLOTS:
