@@ -13,10 +13,10 @@
 
 K_PLUGIN_CLASS_WITH_JSON(ReadOnlyLibarchivePlugin, "kerfuffle_libarchive_readonly.json")
 
-ReadOnlyLibarchivePlugin::ReadOnlyLibarchivePlugin(QObject *parent, const QVariantList & args)
+ReadOnlyLibarchivePlugin::ReadOnlyLibarchivePlugin(QObject *parent, const QVariantList &args)
     : LibarchivePlugin(parent, args)
 {
-    qCDebug(ARK) << "Loaded libarchive read-only plugin";
+    qCDebug(ARK_LOG) << "Loaded libarchive read-only plugin";
 }
 
 ReadOnlyLibarchivePlugin::~ReadOnlyLibarchivePlugin()
